@@ -30,10 +30,12 @@
 XTelepathyPasswordAuthOperation::XTelepathyPasswordAuthOperation(
         const Tp::AccountPtr &account,
         Tp::Client::ChannelInterfaceSASLAuthenticationInterface *saslIface,
+        KTp::WalletInterface *walletInterface,
         bool canTryAgain) :
     Tp::PendingOperation(account),
     m_account(account),
     m_saslIface(saslIface),
+    m_walletInterface(walletInterface),
     m_canTryAgain(canTryAgain)
 {
     connect(m_saslIface,
@@ -50,14 +52,14 @@ void XTelepathyPasswordAuthOperation::onSASLStatusChanged(uint status, const QSt
 {
     if (status == Tp::SASLStatusNotStarted) {
         kDebug() << "Requesting password";
-        promptUser(m_canTryAgain || !KTp::WalletInterface::hasEntry(m_account, QLatin1String("lastLoginFailed")));
+        promptUser(m_canTryAgain || !m_walletInterface->hasEntry(m_account, QLatin1String("lastLoginFailed")));
     } else if (status == Tp::SASLStatusServerSucceeded) {
         kDebug() << "Authentication handshake";
         m_saslIface->AcceptSASL();
     } else if (status == Tp::SASLStatusSucceeded) {
         kDebug() << "Authentication succeeded";
-        if (KTp::WalletInterface::hasEntry(m_account, QLatin1String("lastLoginFailed"))) {
-            KTp::WalletInterface::removeEntry(m_account, QLatin1String("lastLoginFailed"));
+        if (m_walletInterface->hasEntry(m_account, QLatin1String("lastLoginFailed"))) {
+            m_walletInterface->removeEntry(m_account, QLatin1String("lastLoginFailed"));
         }
         setFinished();
     } else if (status == Tp::SASLStatusInProgress) {
@@ -70,7 +72,7 @@ void XTelepathyPasswordAuthOperation::onSASLStatusChanged(uint status, const QSt
             promptUser(false);
         } else {
             kWarning() << "Authentication failed and cannot try again";
-            KTp::WalletInterface::setEntry(m_account, QLatin1String("lastLoginFailed"), QLatin1String("true"));
+            m_walletInterface->setEntry(m_account, QLatin1String("lastLoginFailed"), QLatin1String("true"));
             // We cannot try again, but we can request again to set the account
             // online. A new channel will be created, but since we set the
             // lastLoginFailed entry, next time we will prompt for password
@@ -86,11 +88,11 @@ void XTelepathyPasswordAuthOperation::onSASLStatusChanged(uint status, const QSt
 
 void XTelepathyPasswordAuthOperation::promptUser(bool isFirstRun)
 {
-    if (KTp::WalletInterface::hasPassword(m_account) && isFirstRun) {
+    if (m_walletInterface->hasPassword(m_account) && isFirstRun) {
         m_saslIface->StartMechanismWithData(QLatin1String("X-TELEPATHY-PASSWORD"),
-                                            KTp::WalletInterface::password(m_account).toUtf8());
+                                            m_walletInterface->password(m_account).toUtf8());
     } else {
-        m_dialog = new XTelepathyPasswordPrompt(m_account);
+        m_dialog = new XTelepathyPasswordPrompt(m_account, m_walletInterface);
         connect(m_dialog.data(),
                 SIGNAL(finished(int)),
                 SLOT(onDialogFinished(int)));
@@ -114,7 +116,7 @@ void XTelepathyPasswordAuthOperation::onDialogFinished(int result)
         if (!m_dialog.isNull()) {
             if (m_dialog.data()->savePassword()) {
                 kDebug() << "Saving password in wallet";
-                KTp::WalletInterface::setPassword(m_account, m_dialog.data()->password());
+                m_walletInterface->setPassword(m_account, m_dialog.data()->password());
             }
             m_saslIface->StartMechanismWithData(QLatin1String("X-TELEPATHY-PASSWORD"), m_dialog.data()->password().toUtf8());
             m_dialog.data()->deleteLater();
